@@ -5,7 +5,7 @@ import datetime
 
 from sql import Literal, Null
 from sql.aggregate import Max, Count, Sum
-from sql.conditionals import Case
+from sql.conditionals import Case, Coalesce
 from sql.functions import Extract
 
 from trytond.model import ModelView, ModelSQL, Workflow, fields, \
@@ -71,9 +71,13 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
                 ['converted', 'lost', 'cancelled']),
             },
         depends=['state'])
-    employee = fields.Many2One('company.employee', 'Employee', required=True,
-            states=_STATES_STOP, depends=['state', 'company'],
-            domain=[('company', '=', Eval('company'))])
+    employee = fields.Many2One('company.employee', 'Employee',
+        states={
+            'readonly': _STATES_STOP['readonly'],
+            'required': ~Eval('state').in_(['lead', 'lost', 'cancelled']),
+        },
+        depends=['state', 'company'],
+        domain=[('company', '=', Eval('company'))])
     start_date = fields.Date('Start Date', required=True, select=True,
         states=_STATES_START, depends=_DEPENDS_START)
     end_date = fields.Date('End Date', select=True,
@@ -152,6 +156,9 @@ class SaleOpportunity(Workflow, ModelSQL, ModelView):
             table.drop_constraint('check_percentage')
             table.drop_column('probability')
 
+        # Migration from 4.2: make employee not required
+        table.not_null_action('employee', action='remove')
+
     @classmethod
     def __setup__(cls):
         super(SaleOpportunity, cls).__setup__()
@@ -508,9 +515,9 @@ class SaleOpportunityReportMixin:
     number = fields.Integer('Number')
     converted = fields.Integer('Converted')
     conversion_rate = fields.Function(fields.Float('Conversion Rate',
-        help='In %'), 'get_conversion_rate')
+        digits=(1, 4)), 'get_conversion_rate')
     won = fields.Integer('Won')
-    winning_rate = fields.Function(fields.Float('Winning Rate', help='In %'),
+    winning_rate = fields.Function(fields.Float('Winning Rate', digits=(1, 4)),
         'get_winning_rate')
     lost = fields.Integer('Lost')
     company = fields.Many2One('company.company', 'Company')
@@ -524,12 +531,12 @@ class SaleOpportunityReportMixin:
             digits=(16, Eval('currency_digits', 2)),
             depends=['currency_digits'])
     conversion_amount_rate = fields.Function(fields.Float(
-        'Conversion Amount Rate', help='In %'), 'get_conversion_amount_rate')
+        'Conversion Amount Rate', digits=(1, 4)), 'get_conversion_amount_rate')
     won_amount = fields.Numeric('Won Amount',
         digits=(16, Eval('currency_digits', 2)),
         depends=['currency_digits'])
     winning_amount_rate = fields.Function(fields.Float(
-            'Winning Amount Rate', help='In %'), 'get_winning_amount_rate')
+            'Winning Amount Rate', digits=(1, 4)), 'get_winning_amount_rate')
 
     @staticmethod
     def _converted_state():
@@ -545,13 +552,15 @@ class SaleOpportunityReportMixin:
 
     def get_conversion_rate(self, name):
         if self.number:
-            return float(self.converted) / self.number * 100.0
+            digits = getattr(self.__class__, name).digits[1]
+            return round(float(self.converted) / self.number, digits)
         else:
             return 0.0
 
     def get_winning_rate(self, name):
         if self.number:
-            return float(self.won) / self.number * 100.0
+            digits = getattr(self.__class__, name).digits[1]
+            return round(float(self.won) / self.number, digits)
         else:
             return 0.0
 
@@ -563,13 +572,16 @@ class SaleOpportunityReportMixin:
 
     def get_conversion_amount_rate(self, name):
         if self.amount:
-            return float(self.converted_amount) / float(self.amount) * 100.0
+            digits = getattr(self.__class__, name).digits[1]
+            return round(
+                float(self.converted_amount) / float(self.amount), digits)
         else:
             return 0.0
 
     def get_winning_amount_rate(self, name):
         if self.amount:
-            return float(self.won_amount) / float(self.amount) * 100.0
+            digits = getattr(self.__class__, name).digits[1]
+            return round(float(self.won_amount) / float(self.amount), digits)
         else:
             return 0.0
 
@@ -609,7 +621,7 @@ class SaleOpportunityEmployee(SaleOpportunityReportMixin, ModelSQL, ModelView):
         query = super(SaleOpportunityEmployee, cls).table_query()
         opportunity, = query.from_
         query.columns += (
-            opportunity.employee.as_('id'),
+            Coalesce(opportunity.employee, 0).as_('id'),
             opportunity.employee,
             )
         where = Literal(True)
@@ -694,7 +706,7 @@ class SaleOpportunityEmployeeMonthly(
         query.columns += (
             Max(Extract('MONTH', opportunity.start_date)
                 + Extract('YEAR', opportunity.start_date) * 100
-                + opportunity.employee * 1000000
+                + Coalesce(opportunity.employee, 0) * 1000000
                 ).cast(type_id).as_('id'),
             year_column,
             month_column,
